@@ -14,11 +14,22 @@ import subprocess
 logger = None
 
 class AppServer(Config):
-    bool_options = ['debug', 'log_debug', 'auto_start_servers']
+    bool_options = ['debug', 'log_debug', 'auto_start_servers',
+        'get_public_ip']
     int_options = ['port', 'session_timeout', 'key_bits', 'dh_param_bits']
     path_options = ['log_path', 'db_path', 'www_path', 'data_path',
         'server_cert_path', 'server_key_path']
     str_options = ['bind_addr', 'password']
+    default_options = {
+        'auto_start_servers': True,
+        'get_public_ip': True,
+        'session_timeout': DEFAULT_SESSION_TIMEOUT,
+        'key_bits': DEFAULT_KEY_BITS,
+        'dh_param_bits': DEFAULT_DH_PARAM_BITS,
+        'db_path': DEFAULT_DB_PATH,
+        'www_path': DEFAULT_WWW_PATH,
+        'data_path': DEFAULT_DATA_PATH,
+    }
 
     def __init__(self):
         Config.__init__(self)
@@ -27,7 +38,9 @@ class AppServer(Config):
         self.mem_db = None
         self.interrupt = False
 
-    def get_public_ip(self, retry=False):
+    def load_public_ip(self, retry=False):
+        if not self.get_public_ip:
+            return
         logger.debug('Getting public ip address...')
         try:
             request = urllib2.Request(PUBLIC_IP_SERVER)
@@ -37,13 +50,13 @@ class AppServer(Config):
             if retry:
                 logger.debug('Retrying get public ip address...')
                 time.sleep(1)
-                self.get_public_ip()
+                self.load_public_ip()
             else:
                 logger.exception('Failed to get public ip address...')
 
     def _setup_public_ip(self):
         self.public_ip = None
-        threading.Thread(target=self.get_public_ip).start()
+        threading.Thread(target=self.load_public_ip).start()
 
     def _setup_app(self):
         import flask
@@ -60,13 +73,8 @@ class AppServer(Config):
                 raise flask.abort(401)
 
             # Disable session timeout if set to 0
-            if self.session_timeout is not None:
-                session_timeout = self.session_timeout or None
-            else:
-                session_timeout = DEFAULT_SESSION_TIMEOUT
-
-            if session_timeout and time.time() - flask.session[
-                    'timestamp'] > session_timeout:
+            if self.session_timeout and time.time() - flask.session[
+                    'timestamp'] > self.session_timeout:
                 flask.session.pop('timestamp', None)
                 raise flask.abort(401)
             return call(*args, **kwargs)
@@ -75,7 +83,6 @@ class AppServer(Config):
 
     def _setup_conf(self):
         self.set_path(self.conf_path)
-        data_path = self.data_path or DEFAULT_DATA_PATH
         if not os.path.isdir(self.data_path):
             os.makedirs(self.data_path)
 
@@ -105,7 +112,7 @@ class AppServer(Config):
 
     def _setup_db(self):
         self.mem_db = Database(None)
-        self.app_db = Database(self.db_path or DEFAULT_DB_PATH)
+        self.app_db = Database(self.db_path)
 
     def _close_db(self):
         self.mem_db.close()
@@ -115,19 +122,36 @@ class AppServer(Config):
         import handlers
 
     def _setup_static_handler(self):
-        www_path = self.www_path or DEFAULT_WWW_PATH
-
         from werkzeug import SharedDataMiddleware
 
         self.app.wsgi_app = SharedDataMiddleware(self.app.wsgi_app, {
-            '/': os.path.normpath(www_path),
+            '/': os.path.normpath(self.www_path),
         }, cache=False)
 
         @self.app.route('/', methods=['GET'])
         def index_get():
-            with open(os.path.join(www_path, 'index.html'), 'r') as fd:
+            with open(os.path.join(self.www_path, 'index.html'), 'r') as fd:
                 return fd.read()
 
+    def _upgrade_data(self):
+        from pritunl import __version__
+        version = '0.10.1'
+        version_path = os.path.join(self.data_path, VERSION_NAME)
+        if os.path.isfile(version_path):
+            with open(version_path, 'r') as version_file:
+                version = version_file.readlines()[0].strip()
+
+        if version == '0.10.1':
+            logger.info('Upgrading data from v0.10.1...')
+            from organization import Organization
+            for org in Organization.get_orgs():
+                for user in org.get_users():
+                    user._upgrade_0_10_2()
+
+        if version != __version__:
+            with open(version_path, 'w') as version_file:
+                version = version_file.write('%s\n' % __version__)
+
     def _hash_password(self, password):
         password_hash = hashlib.sha512()
         password_hash.update(password)
@@ -157,6 +181,7 @@ class AppServer(Config):
         self._setup_db()
         self._setup_handlers()
         self._setup_static_handler()
+        self._upgrade_data()
 
     def _setup_server_cert(self):
         if self.server_cert_path and self.server_key_path:
@@ -190,7 +215,7 @@ class AppServer(Config):
         from log_entry import LogEntry
         logger.info('Starting server...')
 
-        if self.auto_start_servers != False:
+        if self.auto_start_servers:
             from pritunl.server import Server
             for server in Server.get_servers():
                 if server.get_orgs():
