@@ -1,6 +1,7 @@
 from pritunl.constants import *
 from pritunl.server import Server
 from pritunl.organization import Organization
+from event import Event
 import pritunl.utils as utils
 from pritunl import app_server
 import flask
@@ -60,7 +61,9 @@ def server_get():
             'protocol': server.protocol,
             'local_network': server.local_network,
             'public_address': server.public_address,
-            'debug': server.debug,
+            'otp_auth': True if server.otp_auth else False,
+            'lzo_compression': server.lzo_compression,
+            'debug': True if server.debug else False,
             'org_count': len(server_orgs),
         }
 
@@ -74,6 +77,7 @@ def server_get():
 @app_server.auth
 def server_put_post(server_id=None):
     name = flask.request.json['name']
+    name = ''.join(x for x in name if x.isalnum() or x in NAME_SAFE_CHARS)
     network = flask.request.json['network']
     interface = flask.request.json['interface']
     port = flask.request.json['port']
@@ -82,7 +86,11 @@ def server_put_post(server_id=None):
     if local_network:
         local_network = local_network
     public_address = flask.request.json['public_address']
-    debug = flask.request.json['debug']
+    public_address = ''.join(
+        x for x in public_address if x.isalnum() or x == '.')
+    debug = True if flask.request.json['debug'] else False
+    otp_auth = True if flask.request.json['otp_auth'] else False
+    lzo_compression = True if flask.request.json['lzo_compression'] else False
 
     # Network
     network_split = network.split('/')
@@ -201,6 +209,8 @@ def server_put_post(server_id=None):
             protocol=protocol,
             local_network=local_network,
             public_address=public_address,
+            otp_auth=otp_auth,
+            lzo_compression=lzo_compression,
             debug=debug,
         )
     else:
@@ -217,9 +227,13 @@ def server_put_post(server_id=None):
         server.protocol = protocol
         server.local_network = local_network
         server.public_address = public_address
+        server.otp_auth = otp_auth
+        server.lzo_compression = lzo_compression
         server.debug = debug
         server.commit()
 
+    Event(type=USERS_UPDATED)
+
     return utils.jsonify({})
 
 @app_server.app.route('/server/<server_id>', methods=['DELETE'])
