@@ -2,7 +2,7 @@ from pritunl.constants import *
 import pritunl.utils as utils
 from pritunl.organization import Organization
 from pritunl.server import Server
-from pritunl import app_server
+from pritunl import app_server, __version__
 
 @app_server.app.route('/status', methods=['GET'])
 @app_server.auth
@@ -27,7 +27,7 @@ def status_get():
             users_count += 1
 
     if not app_server.public_ip:
-        app_server.get_public_ip()
+        app_server.load_public_ip()
 
     return utils.jsonify({
         'orgs_available': orgs_count,
@@ -36,5 +36,6 @@ def status_get():
         'users_total': users_count,
         'servers_online': servers_online_count,
         'servers_total': servers_count,
+        'server_version': __version__,
         'public_ip': app_server.public_ip,
     })
