@@ -8,19 +8,21 @@ import flask
 @app_server.auth
 def user_get(org_id):
     org = Organization(org_id)
-    org_servers = org.get_servers()
+    otp_auth = False
     users = []
     users_dict = {}
     users_sort = []
     clients = {}
 
-    for server in org_servers:
+    for server in org.get_servers():
+        if server.otp_auth:
+            otp_auth = True
         server_clients = server.get_clients()
         for client_id in server_clients:
             client = server_clients[client_id]
             if client_id not in clients:
-                clients[client_id] = []
-            clients[client_id].append(client['virt_address'])
+                clients[client_id] = {}
+            clients[client_id][server.id] = client
 
     for user in org.get_users():
         name_id = '%s_%s' % (user.name, user.id)
@@ -31,7 +33,9 @@ def user_get(org_id):
             'name': user.name,
             'type': user.type,
             'status': True if user.id in clients else False,
-            'virt_addresses': clients[user.id] if user.id in clients else [],
+            'otp_auth': otp_auth,
+            'otp_secret': user.otp_secret,
+            'servers': clients[user.id] if user.id in clients else {},
         }
 
     for name_id in sorted(users_sort):
