@@ -94,7 +94,7 @@ class Organization(Config):
         try:
             conf_path = os.path.join(self.path, TEMP_DIR, 'crl.conf')
             conf_data = CERT_CONF % (self.id, self.path,
-                app_server.key_bits or DEFAULT_KEY_BITS, CA_CERT_ID)
+                app_server.key_bits, CA_CERT_ID)
             with open(conf_path, 'w') as conf_file:
                 conf_file.write(conf_data)
             args = [
