@@ -8,11 +8,13 @@ import tarfile
 import os
 import subprocess
 import logging
+import hashlib
+import base64
 
 logger = logging.getLogger(APP_NAME)
 
 class User(Config):
-    str_options = ['name']
+    str_options = ['name', 'otp_secret']
 
     def __init__(self, org, id=None, name=None, type=None):
         Config.__init__(self)
@@ -58,10 +60,20 @@ class User(Config):
             return self.type
         return Config.__getattr__(self, name)
 
+    def _upgrade_0_10_2(self):
+        if not self.otp_secret:
+            logger.debug('Upgrading user from v0.10.1... %r' % {
+                'org_id': self.org.id,
+                'user_id': self.id,
+            })
+            self._generate_otp_secret()
+            self.commit(0600)
+
     def _initialize(self):
         self._create_ssl_conf()
         self._cert_request()
-        self.commit()
+        self._generate_otp_secret()
+        self.commit(0600)
         self._cert_create()
         self._delete_ssl_conf()
         LogEntry(message='Created new user.')
@@ -114,13 +126,23 @@ class User(Config):
 
     def _create_ssl_conf(self):
         conf_data = CERT_CONF % (self.org.id, self.org.path,
-            app_server.key_bits or DEFAULT_KEY_BITS, self.id)
+            app_server.key_bits, self.id)
         with open(self.ssl_conf_path, 'w') as conf_file:
             conf_file.write(conf_data)
 
     def _delete_ssl_conf(self):
         os.remove(self.ssl_conf_path)
 
+    def _generate_otp_secret(self):
+        sha_hash = hashlib.sha512()
+        sha_hash.update(os.urandom(8192))
+        byte_hash = sha_hash.digest()
+        for i in xrange(6):
+            sha_hash = hashlib.sha512()
+            sha_hash.update(byte_hash)
+            byte_hash = sha_hash.digest()
+        self.otp_secret = base64.b32encode(byte_hash)[:DEFAULT_OTP_SECRET_LEN]
+
     def _load_type(self):
         with open(self.cert_path, 'r') as cert_file:
             cert_data = cert_file.read()
@@ -186,14 +208,19 @@ class User(Config):
                 server.generate_ca_cert()
                 tar_file.add(server.ca_cert_path, arcname=server_cert_arcname)
 
+                client_conf = OVPN_CLIENT_CONF % (
+                    server.protocol,
+                    server.public_address, server.port,
+                    server_cert_arcname,
+                    user_cert_arcname,
+                    user_key_arcname,
+                )
+
+                if server.otp_auth:
+                    client_conf += 'auth-user-pass\n'
+
                 with open(server_conf_path, 'w') as ovpn_conf:
-                    ovpn_conf.write(OVPN_CLIENT_CONF % (
-                        server.protocol,
-                        server.public_address, server.port,
-                        server_cert_arcname,
-                        user_cert_arcname,
-                        user_key_arcname,
-                    ))
+                    ovpn_conf.write(client_conf)
                 tar_file.add(server_conf_path, arcname=server_conf_arcname)
                 os.remove(server_conf_path)
         finally:
