@@ -13,8 +13,3 @@ for line in fileinput.input('../arch/PKGBUILD', inplace=True):
     if 'pkgver=' in line:
         line = 'pkgver=%s' % VERSION
     print line.rstrip('\n')
-
-for line in fileinput.input('../debian/changelog', inplace=True):
-    if 'pritunl (' in line:
-        line = 'pritunl (%s-0ubuntu1) unstable; urgency=low' % VERSION
-    print line.rstrip('\n')
