@@ -11,7 +11,9 @@ define([
       'name': null,
       'type': null,
       'status': null,
-      'virt_addresses': null
+      'otp_auth': null,
+      'otp_secret': null,
+      'servers': null
     },
     url: function() {
       var url = '/user/' + this.get('organization');
